@@ -1,17 +1,17 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::ScrollBox;
 
 use strict;
 use warnings;
 use base qw( Tickit::SingleChildWidget );
-Tickit::Window->VERSION( '0.39' ); # ->scroll_with_children
+Tickit::Window->VERSION( '0.39' ); # ->scroll_with_children, default expose_after_scroll
 use Tickit::Style;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp;
 
@@ -146,7 +146,9 @@ use constant KEYPRESSES_FROM_STYLE => 1;
 
 =cut
 
-=head2 $scrollbox = Tickit::Widget::ScrollBox->new( %args )
+=head2 new
+
+   $scrollbox = Tickit::Widget::ScrollBox->new( %args )
 
 Constructs a new C<Tickit::Widget::ScrollBox> object.
 
@@ -209,7 +211,9 @@ sub cols
    return $self->child->cols + ( $self->vextent ? 1 : 0 );
 }
 
-=head2 $vextent = $scrollbox->vextent
+=head2 vextent
+
+   $vextent = $scrollbox->vextent
 
 Returns the L<Tickit::Widget::ScrollBox::Extent> object representing the box's
 vertical scrolling extent.
@@ -230,7 +234,9 @@ sub _v_visible
    return $vextent->limit > 0;
 }
 
-=head2 $hextent = $scrollbox->hextent
+=head2 hextent
+
+   $hextent = $scrollbox->hextent
 
 Returns the L<Tickit::Widget::ScrollBox::Extent> object representing the box's
 horizontal scrolling extent.
@@ -338,7 +344,6 @@ sub reshape
       }
       else {
          $childwin = $viewport->make_sub( @childgeom );
-         $childwin->set_expose_after_scroll( 1 );
          $child->set_window( $childwin );
       }
    }
@@ -354,7 +359,9 @@ sub window_lost
    undef $self->{viewport};
 }
 
-=head2 $scrollbox->scroll( $downward, $rightward )
+=head2 scroll
+
+   $scrollbox->scroll( $downward, $rightward )
 
 Requests the content be scrolled downward a number of lines and rightward a
 number of columns (either of which which may be negative).
@@ -369,7 +376,9 @@ sub scroll
    $self->hextent->scroll( $rightward ) if $self->hextent and defined $rightward;
 }
 
-=head2 $scrollbox->scroll_to( $top, $left )
+=head2 scroll_to
+
+   $scrollbox->scroll_to( $top, $left )
 
 Requests the content be scrolled such that the given line and column number of
 the child's content is the topmost visible in the container.
