@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::ScrollBox::Extent;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Scalar::Util qw( weaken );
 
@@ -60,7 +60,9 @@ sub set_viewport
 
 =cut
 
-=head2 $viewport = $extent->viewport
+=head2 viewport
+
+   $viewport = $extent->viewport
 
 Returns the size of the viewable portion of the scrollable area (the
 "viewport").
@@ -73,12 +75,16 @@ sub viewport
    return $self->{viewport};
 }
 
-=head2 $total = $extent->total
+=head2 total
+
+   $total = $extent->total
 
 Returns the total size of the scrollable area; which is always at least the
 size of the viewport.
 
-=head2 $extent->set_total( $total )
+=head2 set_total
+
+   $extent->set_total( $total )
 
 Sets the total size of the scrollable area. This method should only be used by
 the child widget, when it is performing smart scrolling.
@@ -113,7 +119,9 @@ sub set_total
    $self->{scrollbox}->_extent_scrolled( $self->{id}, 0, undef );
 }
 
-=head2 $limit = $extent->limit
+=head2 limit
+
+   $limit = $extent->limit
 
 Returns the limit of the offset; the largest value the start offset may be.
 This is simply C<$total - $viewport>, with a limit applied so that it returns
@@ -130,7 +138,9 @@ sub limit
    return $limit;
 }
 
-=head2 $start = $extent->start
+=head2 start
+
+   $start = $extent->start
 
 Returns the start position offset of the viewport within the total area. This
 is always at least zero, and no greater than the limit.
@@ -147,7 +157,9 @@ sub start
 
 =cut
 
-=head2 $extent->scroll( $delta )
+=head2 scroll
+
+   $extent->scroll( $delta )
 
 Requests to move the start by the amount given. This will be clipped if it
 moves outside the allowed range.
@@ -160,7 +172,9 @@ sub scroll
    $self->scroll_to( $self->start + $_[0] );
 }
 
-=head2 $extent->scroll_to( $new_start )
+=head2 scroll_to
+
+   $extent->scroll_to( $new_start )
 
 Requests to move the start to that given. This will be clipped if it is
 outside the allowed range.
@@ -185,7 +199,9 @@ sub scroll_to
    $self->{scrollbox}->_extent_scrolled( $self->{id}, $delta, $start );
 }
 
-=head2 ( $bar_top, $mark_top, $mark_bottom, $bar_bottom ) = $extent->scrollbar_geom( $top, $length )
+=head2 scrollbar_geom
+
+   ( $bar_top, $mark_top, $mark_bottom, $bar_bottom ) = $extent->scrollbar_geom( $top, $length )
 
 Calculates the start and end positions of a scrollbar and the mark within it
 to represent the position of the extent. Returns four integer indexes within
